@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-package Email::MIME::Encode;
+package Email::MIME::Encode 1.951;
 # ABSTRACT: a private helper for MIME header encoding
-$Email::MIME::Encode::VERSION = '1.945';
+
 use Carp ();
 use Encode ();
+use Email::MIME::Header;
 use MIME::Base64();
 use Module::Runtime ();
 use Scalar::Util;
@@ -179,7 +180,17 @@ Email::MIME::Encode - a private helper for MIME header encoding
 
 =head1 VERSION
 
-version 1.945
+version 1.951
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHORS
 
@@ -187,7 +198,7 @@ version 1.945
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =item *
 
