@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Email::MIME::Header;
+package Email::MIME::Header 1.951;
 # ABSTRACT: the header of a MIME message
-$Email::MIME::Header::VERSION = '1.945';
+
 use parent 'Email::Simple::Header';
 
 use Carp ();
@@ -14,7 +14,7 @@ our @CARP_NOT;
 
 our %header_to_class_map;
 
-{
+BEGIN {
   my @address_list_headers = qw(from sender reply-to to cc bcc);
   push @address_list_headers, map { "resent-$_" } @address_list_headers;
   push @address_list_headers, map { "downgraded-$_" } @address_list_headers; # RFC 5504
@@ -75,7 +75,7 @@ sub header_str_set {
     Email::MIME::Encode::maybe_mime_encode_header($name, $_, 'UTF-8')
   } @vals;
 
-  $self->header_set($name => @values);
+  $self->header_raw_set($name => @values);
 }
 
 sub header_str_pairs {
@@ -143,7 +143,7 @@ Email::MIME::Header - the header of a MIME message
 
 =head1 VERSION
 
-version 1.945
+version 1.951
 
 =head1 DESCRIPTION
 
@@ -180,13 +180,23 @@ module due to L<bugs in MIME-Header|Encode::MIME::Header/BUGS>.
 Alternately, if you have Unicode (character) strings to set in headers, use the
 C<header_str_set> method.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =item *
 
